@@ -28,7 +28,7 @@ def basic_table(read_type, sheet_name, read_path, columns_to_keep, columns_renam
         elif operator == "<=":
             df_basic_table = df_basic_table[df_basic_table[column] <= value]
 
-    df_basic_table = df_basic_table.groupby(group_by).aggregate(aggregate_columns)
+    df_basic_table = df_basic_table.groupby(group_by).aggregate(aggregate_columns).reset_index()
 
     return df_basic_table
 
